apikey

package
v0.0.15 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewChain

func NewChain(providers ...mackerel.APIKeyProvider) mackerel.APIKeyProvider

NewChain searches a valid provider from providers.

func NewEnvironment

func NewEnvironment(name string) mackerel.APIKeyProvider

NewEnvironment returns a provider which gets a static api key from the environment values.

func NewStatic

func NewStatic(apikey string) mackerel.APIKeyProvider

NewStatic returns a provider which provides a static api key.

Types

This section is empty.

Directories

Path Synopsis

Jump to