Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewChain ¶
func NewChain(providers ...mackerel.APIKeyProvider) mackerel.APIKeyProvider
NewChain searches a valid provider from providers.
func NewEnvironment ¶
func NewEnvironment(name string) mackerel.APIKeyProvider
NewEnvironment returns a provider which gets a static api key from the environment values.
func NewStatic ¶
func NewStatic(apikey string) mackerel.APIKeyProvider
NewStatic returns a provider which provides a static api key.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.